@@ -47,12 +47,18 @@ impl KubeResource<Pod> for KubePod {
     let (status, cr, restarts, c_stats_len, containers) = match &pod.status {
       Some(status) => {
         let (mut cr, mut rc) = (0, 0);
-        status.container_statuses.iter().for_each(|cs| {
-          if cs.ready {
-            cr += 1;
+        let c_stats_len = match status.container_statuses.as_ref() {
+          Some(c_stats) => {
+            c_stats.iter().for_each(|cs| {
+              if cs.ready {
+                cr += 1;
+              }
+              rc += cs.restart_count;
+            });
+            c_stats.len()
           }
-          rc += cs.restart_count;
-        });
+          None => 0,
+        };
 
         let mut containers: Vec<KubeContainer> = pod
           .spec
@@ -76,6 +82,8 @@ impl KubeResource<Pod> for KubePod {
           .as_ref()
           .unwrap_or(&PodSpec::default())
           .init_containers
+          .as_ref()
+          .unwrap_or(&vec![])
           .iter()
           .map(|c| {
             KubeContainer::from_api(
@@ -91,13 +99,7 @@ impl KubeResource<Pod> for KubePod {
         // merge containers and init-containers into single array
         containers.append(&mut init_containers);
 
-        (
-          get_status(status, pod),
-          cr,
-          rc,
-          status.container_statuses.len(),
-          containers,
-        )
+        (get_status(status, pod), cr, rc, c_stats_len, containers)
       }
       _ => (UNKNOWN.into(), 0, 0, 0, vec![]),
     };
@@ -127,15 +129,17 @@ impl KubeContainer {
     container: &Container,
     pod_name: String,
     age: String,
-    c_stats: &[ContainerStatus],
+    c_stats: &Option<Vec<ContainerStatus>>,
     init: bool,
   ) -> Self {
     let (mut ready, mut status, mut restarts) = ("false".to_string(), "<none>".to_string(), 0);
-    let c_stat = c_stats.iter().find(|cs| cs.name == container.name);
-    if let Some(c_stat) = c_stat {
-      ready = c_stat.ready.to_string();
-      status = get_container_state(c_stat.state.clone());
-      restarts = c_stat.restart_count;
+    if let Some(c_stats) = c_stats {
+      let c_stat = c_stats.iter().find(|cs| cs.name == container.name);
+      if let Some(c_stat) = c_stat {
+        ready = c_stat.ready.to_string();
+        status = get_container_state(c_stat.state.clone());
+        restarts = c_stat.restart_count;
+      }
     }
 
     KubeContainer {
@@ -147,7 +151,7 @@ impl KubeContainer {
       restarts,
       liveliness_probe: container.liveness_probe.is_some(),
       readiness_probe: container.readiness_probe.is_some(),
-      ports: get_container_ports(&container.ports),
+      ports: get_container_ports(&container.ports).unwrap_or_default(),
       age,
       init,
     }
@@ -188,89 +192,94 @@ fn get_status(stat: &PodStatus, pod: &Pod) -> String {
   };
 
   // get int container status
-  let status = {
-    for (i, cs) in stat.init_container_statuses.iter().enumerate() {
-      let status = match &cs.state {
-        Some(s) => {
-          if let Some(st) = &s.terminated {
-            if st.exit_code == 0 {
-              "".into()
-            } else if st.reason.as_ref().unwrap_or(&String::default()).is_empty() {
-              format!("Init:{}", st.reason.as_ref().unwrap())
-            } else if st.signal.unwrap_or_default() != 0 {
-              format!("Init:Signal:{}", st.signal.unwrap())
+  let status = match &stat.init_container_statuses {
+    Some(ics) => {
+      for (i, cs) in ics.iter().enumerate() {
+        let status = match &cs.state {
+          Some(s) => {
+            if let Some(st) = &s.terminated {
+              if st.exit_code == 0 {
+                "".into()
+              } else if st.reason.as_ref().unwrap_or(&String::default()).is_empty() {
+                format!("Init:{}", st.reason.as_ref().unwrap())
+              } else if st.signal.unwrap_or_default() != 0 {
+                format!("Init:Signal:{}", st.signal.unwrap())
+              } else {
+                format!("Init:ExitCode:{}", st.exit_code)
+              }
+            } else if is_pod_init(s.waiting.clone()) {
+              format!(
+                "Init:{}",
+                s.waiting
+                  .as_ref()
+                  .unwrap()
+                  .reason
+                  .as_ref()
+                  .unwrap_or(&String::default())
+              )
             } else {
-              format!("Init:ExitCode:{}", st.exit_code)
+              format!(
+                "Init:{}/{}",
+                i,
+                pod
+                  .spec
+                  .as_ref()
+                  .and_then(|ps| ps.init_containers.as_ref().map(|pic| pic.len()))
+                  .unwrap_or(0)
+              )
             }
-          } else if is_pod_init(s.waiting.clone()) {
-            format!(
-              "Init:{}",
-              s.waiting
-                .as_ref()
-                .unwrap()
-                .reason
-                .as_ref()
-                .unwrap_or(&String::default())
-            )
-          } else {
-            format!(
-              "Init:{}/{}",
-              i,
-              pod
-                .spec
-                .as_ref()
-                .map(|ps| ps.init_containers.len())
-                .unwrap_or(0)
-            )
           }
+          None => "".into(),
+        };
+        if !status.is_empty() {
+          return status;
         }
-        None => "".into(),
-      };
-      if !status.is_empty() {
-        return status;
       }
+      status
     }
-    status
+    None => status,
   };
 
-  let (mut status, running) = {
-    let mut running = false;
-    let status = stat
-      .container_statuses
-      .iter()
-      .rev()
-      .find_map(|cs| {
-        cs.state.as_ref().and_then(|s| {
-          if cs.ready && s.running.is_some() {
-            running = true;
-          }
-          if s
-            .waiting
-            .as_ref()
-            .and_then(|w| w.reason.as_ref().map(|v| !v.is_empty()))
-            .unwrap_or_default()
-          {
-            s.waiting.as_ref().and_then(|w| w.reason.clone())
-          } else if s
-            .terminated
-            .as_ref()
-            .and_then(|w| w.reason.as_ref().map(|v| !v.is_empty()))
-            .unwrap_or_default()
-          {
-            s.terminated.as_ref().and_then(|w| w.reason.clone())
-          } else if let Some(st) = &s.terminated {
-            if st.signal.unwrap_or_default() != 0 {
-              Some(format!("Signal:{}", st.signal.unwrap_or_default()))
-            } else {
-              Some(format!("ExitCode:{}", st.exit_code))
+  let (mut status, running) = match &stat.container_statuses {
+    Some(css) => {
+      let mut running = false;
+      let status = css
+        .iter()
+        .rev()
+        .find_map(|cs| {
+          cs.state.as_ref().and_then(|s| {
+            if cs.ready && s.running.is_some() {
+              running = true;
             }
-          } else {
-            None
-          }
+            if s
+              .waiting
+              .as_ref()
+              .and_then(|w| w.reason.as_ref().map(|v| !v.is_empty()))
+              .unwrap_or_default()
+            {
+              s.waiting.as_ref().and_then(|w| w.reason.clone())
+            } else if s
+              .terminated
+              .as_ref()
+              .and_then(|w| w.reason.as_ref().map(|v| !v.is_empty()))
+              .unwrap_or_default()
+            {
+              s.terminated.as_ref().and_then(|w| w.reason.clone())
+            } else if let Some(st) = &s.terminated {
+              if st.signal.unwrap_or_default() != 0 {
+                Some(format!("Signal:{}", st.signal.unwrap_or_default()))
+              } else {
+                Some(format!("ExitCode:{}", st.exit_code))
+              }
+            } else {
+              Some(status.clone())
+            }
+          })
         })
-      })
-      .unwrap_or(status);
-    (status, running)
+        .unwrap_or_default();
+      (status, running)
+    }
+    None => (status, false),
   };
 
   if running && status == "Completed" {
@@ -289,24 +298,26 @@ fn is_pod_init(sw: Option<ContainerStateWaiting>) -> bool {
     .unwrap_or_default()
 }
 
-fn get_container_ports(ports: &[ContainerPort]) -> String {
-  ports
-    .iter()
-    .map(|c_port| {
-      let mut port = String::new();
-      if let Some(name) = c_port.name.clone() {
-        port = format!("{}:", name);
-      }
-      port = format!("{}{}", port, c_port.container_port);
-      if let Some(protocol) = c_port.protocol.clone() {
-        if protocol != "TCP" {
-          port = format!("{}/{}", port, c_port.protocol.clone().unwrap());
+fn get_container_ports(ports: &Option<Vec<ContainerPort>>) -> Option<String> {
+  ports.as_ref().map(|ports| {
+    ports
+      .iter()
+      .map(|c_port| {
+        let mut port = String::new();
+        if let Some(name) = c_port.name.clone() {
+          port = format!("{}:", name);
         }
-      }
-      port
-    })
-    .collect::<Vec<_>>()
-    .join(", ")
+        port = format!("{}{}", port, c_port.container_port);
+        if let Some(protocol) = c_port.protocol.clone() {
+          if protocol != "TCP" {
+            port = format!("{}/{}", port, c_port.protocol.clone().unwrap());
+          }
+        }
+        port
+      })
+      .collect::<Vec<_>>()
+      .join(", ")
+  })
 }
 
 #[cfg(test)]
